<?php
/**
 * Class helper for admin settings
 *
 * @package bp-profile-visibility-pmpro-addon
 */

// Exit if file access directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class BP_Profile_Visibility_Pmpro_Settings_Helper
 */
class BP_Profile_Visibility_Pmpro_Settings_Helper {

	/**
	 * BP_Profile_Visibility_Pmpro_Settings_Helper constructor.
	 */
	public function __construct() {
		$this->setup();
	}

	/**
	 * Callbacks
	 */
	private function setup() {
		add_action( 'bp_profile_visibility_settings', array( $this, 'register_settings' ) );
	}

	/**
	 * Register plugin settings
	 */
	public function register_settings( $page ) {

		$levels = bp_profile_visibility_pmpro()->get_pmpro_levels( true );

		foreach ( $levels as $level ) {
			$name   = $level->name;
			$prefix = 'pmpro_bppv_' . $level->id;

			$section = $page->add_section( $prefix, $name );
			$fields = array(
				array(
					'name'    => $prefix . '_bp_profile_visibility',
					'label'   => __( 'Default profile Visibility?', 'bp-profile-visibility-manager' ),
					// You already know it from previous example.
					'desc'    => __( 'Set default profile visibility for new users.', 'bp-profile-visibility-manager' ),
					// This is used as the description of the field.
					'type'    => 'select',
					'default' => 'public',
					'options' => bp_profile_visibility_get_visibilities(),
				),
				array(
					'name'    => $prefix . '_bp_friends_list_visibility',
					'label'   => __( 'Default friends list  Visibility?', 'bp-profile-visibility-manager' ),
					// You already know it from previous example.
					'desc'    => __( 'Set default profile visibility for friends list.', 'bp-profile-visibility-manager' ),
					// This is used as the description of the field.
					'type'    => 'select',
					'default' => 'public',
					'options' => bp_profile_visibility_get_visibilities(),
				),

				array(
					'name'    => $prefix . '_bp_hide_last_active',
					'label'   => __( 'Hide Last Active?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, It will not show when the user was last active.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'yes',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => $prefix . '_bp_exclude_in_search',
					'label'   => __( 'Exclude Users from Members search?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, It will hide users from search by default.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => $prefix . '_bp_exclude_in_dir',
					'label'   => __( 'Exclude Users from Members directory?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, It will hide users from members directory when they register.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => $prefix . '_bp_allow_friendship_request',
					'label'   => __( 'Enable Friendship request by default?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, users will recieve new friends request.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'yes',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),

				),
			);

			$section->add_fields( $fields );
		}
	}
}

new BP_Profile_Visibility_Pmpro_Settings_Helper();

