<?php
/**
 * Plugin name: BuddyPress Profile Visibility For PMPRO
 * Description: An addon for BuddyPress Profile Visibility and PMPRO. allows assigning default profile visibility settings for each level of pmpro separately.
 * Version: 1.0.1
 * Author: BuddyDev Team
 * Author URI: https://buddydev.com/
 */

// Exit if file access directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class BP_Profile_Visibility_Pmpro_Addon
 */
class BP_Profile_Visibility_Pmpro_Addon {

	/**
	 * Class instance
	 *
	 * @var BP_Profile_Visibility_Pmpro_Addon
	 */
	private static $instance = null;

	/**
	 * Plugin directory absolute path
	 *
	 * @var string
	 */
	private $path;

	/**
	 * BP_Profile_Visibility_Pmpro_Addon constructor.
	 */
	private function __construct() {
		$this->path = plugin_dir_path( __FILE__ );
		$this->setup();
	}

	/**
	 * Get class instance
	 *
	 * @return BP_Profile_Visibility_Pmpro_Addon
	 */
	public static function get_instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Setup hooks.
	 */
	private function setup() {
		add_action( 'plugins_loaded', array( $this, 'load' ), 999 );
	}

	/**
	 * Load other plugin files
	 */
	public function load() {

		if ( ! function_exists( 'bp_profile_visibility_loader' ) || ! function_exists( 'pmpro_getAllLevels' ) ) {
			return;
		}

		$files = array(
			'core/class-bp-profile-visibility-pmpro-action-handler.php',
		);

		if ( is_admin() && ! defined( 'DOING_AJAX' ) ) {
			$files[] = 'admin/class-bp-profile-visibility-pmpro-settings-helper.php';
		}

		foreach ( $files as $file ) {
			require_once $this->path . $file;
		}
	}

	/**
	 * Get plugin path
	 *
	 * @return string
	 */
	public function get_path() {
		return $this->path;
	}

	/**
	 * Get all pmpro levels
	 *
	 * @param bool $include_hidden Include hidden membership or not.
	 *
	 * @return array
	 */
	public function get_pmpro_levels( $include_hidden = false ) {
		return pmpro_getAllLevels( $include_hidden );
	}
}

/**
 * Get class instance
 *
 * @return BP_Profile_Visibility_Pmpro_Addon
 */
function bp_profile_visibility_pmpro() {
	return BP_Profile_Visibility_Pmpro_Addon::get_instance();
}

bp_profile_visibility_pmpro();
