<?php
/**
 * Action handler for pmpro actions
 *
 * @package bp-profile-visibility-pmpro-addon
 */

// Exit if file access directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class BP_Profile_Visibility_Pmpro_Action_Handler
 */
class BP_Profile_Visibility_Pmpro_Action_Handler {

	/**
	 * BP_Profile_Visibility_Pmpro_Action_Handler constructor.
	 */
	public function __construct() {
		$this->setup();
	}

	/**
	 * Setup callbacks on various pmpro actions.
	 */
	public function setup() {
		add_action( 'pmpro_after_change_membership_level', array( $this, 'apply_level_default_settings' ), 10, 3 );
		add_action( 'pmpro_membership_post_membership_expiry', array( $this, 'apply_default_settings' ), 10, 2 );
	}

	/**
	 * Apply settings of this level
	 *
	 * @param int $level_id Level id change to.
	 * @param int $user_id User level changing.
	 * @param int $cancel_level Cancel level.
	 */
	public function apply_level_default_settings( $level_id, $user_id, $cancel_level ) {

		$level_settings = $this->get_level_settings( $level_id );

		if ( empty( $level_settings ) ) {
			return;
		}

		foreach ( $level_settings as $key => $value ) {
			update_user_meta( $user_id, $key, $value );
		}
	}

	/**
	 * Apply default settings to user when his/her membership expired
	 *
	 * @param int $user_id user id of user who's membership expired.
	 * @param int $level_id Level id which is expired.
	 */
	public function apply_default_settings( $user_id, $level_id ) {

		$allowed_keys = bp_profile_visibility_get_allowed_keys();

		$settings = get_option( 'bp_profile_visibility_settings' );

		if ( empty( $settings ) ) {
			return;
		}

		foreach ( $settings as $setting => $value ) {

			if ( in_array( $setting, $allowed_keys ) ) {
				update_user_meta( $user_id, $setting, $value );
			}
		}
	}

	/**
	 * Get level settings
	 *
	 * @param string $level_id Level name.
	 *
	 * @return array
	 */
	private function get_level_settings( $level_id = '' ) {
		$settings = get_option( 'bp_profile_visibility_settings' );

		if ( empty( $settings ) ) {
			return array();
		}

		$prefix = "pmpro_bppv_{$level_id}_";

		$level_settings = array();

		foreach ( $settings as $key => $value ) {

			if ( strpos( $key, $prefix ) === 0 ) {
				$key                    = str_replace( $prefix, '', $key );
				$level_settings[ $key ] = $value;
			}
		}

		return $level_settings;
	}
}

new BP_Profile_Visibility_Pmpro_Action_Handler();
